function W = CalcW3(DataDim,Niter, rule, alpha)



% Check for inputs
if round(Niter*alpha) <1
    error('alpha value is too small! Reduce it or increase the number of itaerations')
end


MaxN = DataDim(1);
MaxM = DataDim(2);

% Initialize outputs
WDIST = zeros(Niter,MaxM);
WDIST(:,1) = -Inf;

disp('Data size:')
disp(sprintf('%i objects, %i variables', MaxN, MaxM))
disp(' ');
disp(sprintf('W reference distribution will be generated with %i permutations using %s rule',Niter, rule))
disp(' ');
if Niter < 1001; disp('The number of permutations is <= 1000. Consider increasing it.'); end
disp(' ');
disp('Generating W')


%Permutation
i = 0;
for m = 2:MaxM
    i = i +1;
    disp(sprintf('Running for %i x %i variables', MaxN, m));
    
    k = 0;
    for j = 1 : Niter
        
        k = k + 1;
        
        Xsubset = zscore(randn(MaxN,m));
        
        layer.alpha = mean(Xsubset);
        [uX,sX,vX] = svds((Xsubset - repmat(layer.alpha,size(Xsubset,1),1)),1);
        layer.lambda = uX*sX;
        layer.kappa  = vX;
        
        layer.multX=layer.lambda*layer.kappa' + repmat(layer.alpha,size(Xsubset,1),1);
       
        layer.SSQ = sum(sum(layer.multX.^2));
        
        %Scalinf
        [I, J] = size(Xsubset);
        if J <=I
            Rscale = J*(I-1);
        elseif J> I
            Rscale = (J-1)*I;
        end
       
        WDIST(k,i) = layer.SSQ./Rscale;
        
        
    end
    
end


%%%%%%%%%%%%%%%%%



W = zeros(1,size(WDIST,2));

if strcmp(rule,'min') == 1
    
    for m = 1:size(WDIST,2)
        
        W(m) = min(WDIST(:,m));
    end
    
    
elseif strcmp(rule,'alpha') == 1
    for m  = 1:size(WDIST,2)
        
        WDISTsort = sort(WDIST(:, m), 'ascend');
        
        index = round((1-alpha)*length(WDISTsort));
        
        W(m) = WDISTsort(index);
        
        clear WDISTsort index
    end
end


return





