% Copyright 2013 Biosystems Data Analysis Group; Universiteit van Amsterdam
%
% This is a license to use and modify SOFTWARE & DATA produced by:
% THE BIOSYSTEMS DATA ANALYSIS GROUP OF THE UNIVERSITEIT VAN AMSTERDAM

% If you use, modify or redistribute the SOFTWARE & DATA and/or your source modifications, you agree: 
% i)	to use the SOFTWARE & DATA and/or your source modifications solely as part of your research and not in any commercial product; 
%	
% ii)	that the SOFTWARE  & DATA and/or your source modifications will not be distributed for profit; 

% iii)	all copyright notices and this license note with the SOFTWARE & DATA are retained any  redistribution of the SOFTWARE & DATA, or any portion thereof; 
%
% iv)	to indemnify, hold harmless, and defend the "Biosystems Data Analysis Group of the Universiteit van Amsterdam" from and against any claims or lawsuits that arise or result from the use of the SOFTWARE & DATA or your source modifications. 
%
% v)	to properly reference the SOFTWARE & DATA when used in your reseach in any publication that may result from that research.
%	
% Reserved Rights. The "Biosystems Data Analysis Group of the Universiteit
% van Amsterdam" retain title and all ownership rights to the SOFTWARE & DATA.


% Example dataset is provided, here we give a description on experimental 
% details associated with the dataset (the dataset is also used in the
% original manuscript [1].
% Escherichia coli NST 74, a phenylalanine overproducing strain and E. coli W3110, 
% a wild type strain, were grown in batch fermentations at 30 C in a Bioflow II 
% (New Brunswick Scientific) bioreactor as previously described [2]. Cells were 
% cultivated on MMT12 medium with glucose as carbon source, a constant pH and 
% a constant oxygen tension of 30%. Samples were taken at 16, 24, 40 and 48 hours 
% and analyzed by GC-MS and LC-MS. Peaks related to the substrates used for growth 
% (glucose and succinate) were removed from the data. The resulting data set consisted 
% of 28 measurements and 188 metabolites. Extensive details on experimental setup, 
% GC-MS and LC-MS analysis and subsequent preprocessing can be found in [2].
% 
% [1] Saccenti E, Westerhuis JA, Smilde AK, van der Werf MJ, Hageman JA, Hendriks MM. 
% Simplivariate models: uncovering the underlying biology in functional genomics data.
% PLoS One. 2011;6(6):e20747. doi: 10.1371/journal.pone.0020747. Epub 2011 Jun 16.
% 
% [2] Smilde A, van der Werf M, Bijlsma S, van der Werff-van B, Jellema R (2005) Fusion 
% of mass spectrometry-based metabolomics data. Analytical Chemistry 77: 67296736. 
% 
% For further interest in performing similar fermentation and analytical experiments at 
% TNO please refer to Cornelis Mijnders (cornelis.mijnders@tno.nl) or www.tno.nl



% loading raw data ECOLI
load('DemoColiAn.mat');
data=DemoColiAn.DataGCLCInt;
metabolitesNames = DemoColiAn.FancyVlblGCLCInt;

% Calculate W
rule = 'alpha'; alpha = 0.01; Niter = 101;
DataDim = size(data);
%W = CalcW(DataDim, Niter, rule, alpha);

W = CalcW(DataDim,Niter, rule, alpha);

%It is suggested to save W for further re-use

% run simply algorithm
NoComp = 3;
decomposition = simply(data,W,NoComp);

% Transfer to Excle file the decompostion results
xlsfile = 'results.xls';


% This saves the results to an excel file
Decomp2Excel(decomposition, metabolitesNames, xlsfile);

% This make a graphical output of the results
showDecomp(decomposition, metabolitesNames);